@@ -6,6 +6,7 @@ from pathlib import Path
 
 from PySide6.QtGui import (
     QFont,
+    QFontDatabase,
     QFontMetrics,
     QImage,
     QTextCharFormat,
@@ -41,8 +42,12 @@ class MarkdownEditor(QTextEdit):
         self.setAcceptRichText(False)
 
         # Normal text
-        self.qfont = QFont()
-        self.qfont.setPointSize(11)
+        base_dir = Path(__file__).resolve().parent
+        font_path = base_dir / "fonts" / "NotoSansSymbols2-Regular.ttf"
+        font_id = QFontDatabase.addApplicationFont(str(font_path))
+        families = QFontDatabase.applicationFontFamilies(font_id)
+        font_family = families[0]
+        self.qfont = QFont(font_family, 11)
         self.setFont(self.qfont)
 
         self._apply_line_spacing()  # 1.25× initial spacing
@@ -546,6 +551,7 @@ class MarkdownEditor(QTextEdit):
                 c.setPosition(new_pos)
                 self.setTextCursor(c)
                 return
+
         # Step out of a code block with Down at EOF
         if event.key() == Qt.Key.Key_Down:
             c = self.textCursor()
@@ -753,19 +759,6 @@ class MarkdownEditor(QTextEdit):
                 super().keyPressEvent(event)
                 return
 
-            # Auto-insert an extra blank line after headings (#, ##, ###)
-            # when pressing Enter at the end of the line.
-            if re.match(r"^#{1,3}\s+", stripped) and pos_in_block >= len(line_text):
-                cursor.beginEditBlock()
-                # First blank line: visual separator between heading and body
-                cursor.insertBlock()
-                # Second blank line: where body text will start (caret ends here)
-                cursor.insertBlock()
-                cursor.endEditBlock()
-
-                self.setTextCursor(cursor)
-                return
-
             # Check for list continuation
             list_type, prefix = self._detect_list_type(current_line)
 
