@@ -110,7 +110,8 @@ class ToolBar(QToolBar):
         self.actInsertImg.triggered.connect(self.insertImageRequested)
 
         # History button
-        self.actHistory = QAction(strings._("history"), self)
+        self.actHistory = QAction("⎌", self)
+        self.actHistory.setToolTip(strings._("history"))
         self.actHistory.triggered.connect(self.historyRequested)
 
         # Set exclusive buttons in QActionGroups
@@ -178,7 +179,7 @@ class ToolBar(QToolBar):
         self._style_letter_button(self.actAlarm, "⏰")
 
         # History
-        self._style_letter_button(self.actHistory, strings._("view_history"))
+        self._style_letter_button(self.actHistory, "⎌")
 
     def _style_letter_button(
         self,
